@@ -5,7 +5,7 @@ import mimetypes
 import asyncio
 from tornado.ioloop import IOLoop
 import time
-from .constants import (NB_TYPE,UNTITLED_FILE,FOLDER_SEPERATOR,UNTITLED_NB,UNTITLED_FOLDER,CHECKPOINT_NAME,PUT_HELPERS,READ_HELPERS)
+from .constants import (NB_TYPE,UNTITLED_FILE,FOLDER_SEPERATOR,UNTITLED_NB,UNTITLED_FOLDER,CHECKPOINT_NAME)
 
 from tornado.web import HTTPError as HTTPServerError
 import base64
@@ -69,7 +69,19 @@ def _head_object(config, bucket, key):
             return True
     return False
 
+READ_HELPERS = {
+('directory', 'json'): _get_folder,
+('notebook', 'json'): _get_notebook,
+('file', 'text'): _get_text_file,
+('file', 'base64'): _get_base64_file
+}
 
+PUT_HELPERS = {
+   ('file', 'base64'):  _save_base64_file,
+    ('notebook', 'json'): _save_notebook,
+    ('directory', 'json'): _save_folder,
+    ('file', 'text'): _save_text_file
+}
 
 @gen.coroutine
 def _put_object(config, bucket, body, object_name):
@@ -131,6 +143,7 @@ def _list_objects(config, bucket, prefix, delimiter, max_keys, token=''):
             Prefix=prefix)
 
 
+
 def _get_key(config, path):
     return config.prefix + path.lstrip('/')
 
